@@ -34,7 +34,6 @@
 
 #include "kleopatra_debug.h"
 #include <KLocalizedString>
-#include <kwidgetsaddons_version.h>
 
 using namespace Kleo;
 using namespace Kleo::Commands;
@@ -170,22 +169,14 @@ void CertifyCertificateCommand::doStart()
     };
 
     if (!findAnyGoodKey()) {
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
         auto sel =
             KMessageBox::questionTwoActions(d->parentWidgetOrView(),
-#else
-        auto sel = KMessageBox::questionYesNo(d->parentWidgetOrView(),
-#endif
                                             xi18nc("@info", "To certify other certificates, you first need to create an OpenPGP certificate for yourself.")
                                                 + QStringLiteral("<br><br>") + i18n("Do you wish to create one now?"),
                                             i18n("Certification Not Possible"),
                                             KGuiItem(i18n("Create")),
                                             KStandardGuiItem::cancel());
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
         if (sel == KMessageBox::ButtonCode::PrimaryAction) {
-#else
-        if (sel == KMessageBox::Yes) {
-#endif
             QEventLoop loop;
             auto cmd = new NewOpenPGPCertificateCommand;
             cmd->setParentWidget(d->parentWidgetOrView());
@@ -238,23 +229,25 @@ void CertifyCertificateCommand::Private::slotDialogRejected()
 
 void CertifyCertificateCommand::Private::slotResult(const Error &err)
 {
-    if (!err && !err.isCanceled() && dialog && dialog->exportableCertificationSelected() && dialog->sendToServer()) {
-        auto const cmd = new ExportOpenPGPCertsToServerCommand(target);
-        cmd->start();
-    } else if (!err) {
-        information(i18n("Certification successful."),
-                    i18n("Certification Succeeded"));
-    } else {
+    if (err.isCanceled()) {
+        // do nothing
+    } else if (err) {
         error(i18n("<p>An error occurred while trying to certify<br/><br/>"
                    "<b>%1</b>:</p><p>\t%2</p>",
               Formatting::formatForComboBox(target),
               QString::fromUtf8(err.asString())),
               i18n("Certification Error"));
+    } else if (dialog && dialog->exportableCertificationSelected() && dialog->sendToServer()) {
+        auto const cmd = new ExportOpenPGPCertsToServerCommand(target);
+        cmd->start();
+    } else {
+        information(i18n("Certification successful."),
+                    i18n("Certification Succeeded"));
     }
+
     if (!dialog->tags().isEmpty()) {
         Tags::enableTags();
     }
-
     finished();
 }
 
@@ -281,7 +274,6 @@ void CertifyCertificateCommand::Private::slotCertificationPrepared()
     job->setNonRevocable(dialog->nonRevocableCertificationSelected());
     job->setUserIDsToSign(userIdIndexes);
     job->setSigningKey(dialog->selectedSecretKey());
-    job->setCheckLevel(dialog->selectedCheckLevel());
     if (!dialog->tags().isEmpty()) {
         // do not set an empty remark to avoid an empty signature notation (GnuPG bug T5142)
         job->setRemark(dialog->tags());
@@ -336,8 +328,13 @@ void CertifyCertificateCommand::Private::createJob()
         return;
     }
 
-    connect(j, &Job::progress,
+#if QGPGME_JOB_HAS_NEW_PROGRESS_SIGNALS
+    connect(j, &QGpgME::Job::jobProgress,
             q, &Command::progress);
+#else
+    connect(j, &QGpgME::Job::progress,
+            q, [this](const QString &, int current, int total) { Q_EMIT q->progress(current, total); });
+#endif
     connect(j, &SignKeyJob::result, q, [this](const GpgME::Error &result) { slotResult(result); });
 
     job = j;
