@@ -115,8 +115,8 @@ ChecksumVerifyFilesCommand::ChecksumVerifyFilesCommand(const QStringList &files,
 void ChecksumVerifyFilesCommand::Private::init()
 {
     controller.setExecutionContext(shared_qq);
-    connect(&controller, SIGNAL(done()), q, SLOT(slotControllerDone()));
-    connect(&controller, SIGNAL(error(int,QString)), q, SLOT(slotControllerError(int,QString)));
+    connect(&controller, &Controller::done, q, [this]() { slotControllerDone(); });
+    connect(&controller, &Controller::error, q, [this](int err, const QString &details) { slotControllerError(err, details); });
 }
 
 ChecksumVerifyFilesCommand::~ChecksumVerifyFilesCommand()
