@@ -7,8 +7,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef __KLEOPATRA_CRYPTO_RECIPIENT_H__
-#define __KLEOPATRA_CRYPTO_RECIPIENT_H__
+#pragma once
 
 #include <gpgme++/global.h>
 
@@ -84,4 +83,3 @@ inline bool operator!=(const Recipient &lhs, const Recipient &rhs)
 } // namespace Crypto
 } // namespace Kleo
 
-#endif /* __KLEOPATRA_CRYPTO_RECIPIENT_H__ */
