@@ -73,10 +73,12 @@ static_assert(sizeof prettyFlags / sizeof * prettyFlags == Card::NumStates, "");
 
 Q_DECLARE_METATYPE(GpgME::Error)
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 5, 0)
 static QDebug operator<<(QDebug s, const std::string &string)
 {
     return s << QString::fromStdString(string);
 }
+#endif
 
 namespace
 {
@@ -435,19 +437,8 @@ static void readKeyPairInfoFromPIVCard(const std::string &keyRef, PIVCard *pivCa
         qCWarning(KLEOPATRA_LOG) << "Running" << command << "failed:" << err;
         return;
     }
-    for (const auto &pair: keyPairInfoLines) {
-        if (pair.first == "KEYPAIRINFO") {
-            const KeyPairInfo info = KeyPairInfo::fromStatusLine(pair.second);
-            if (info.grip.empty()) {
-                qCWarning(KLEOPATRA_LOG) << "Invalid KEYPAIRINFO status line"
-                        << QString::fromStdString(pair.second);
-                continue;
-            }
-            pivCard->setKeyAlgorithm(keyRef, info.algorithm);
-        } else {
-            logUnexpectedStatusLine(pair, "readKeyPairInfoFromPIVCard()", command);
-        }
-    }
+    // this adds the key algorithm (and the key creation date, but that seems to be unset for PIV) to the existing key pair information
+    pivCard->setCardInfo(keyPairInfoLines);
 }
 
 static void readCertificateFromPIVCard(const std::string &keyRef, PIVCard *pivCard, const std::shared_ptr<Context> &gpg_agent)
@@ -531,8 +522,8 @@ static void handle_netkey_card(std::shared_ptr<Card> &ci, std::shared_ptr<Contex
         return;
     }
 
-    if (ci->appVersion() != 3) {
-        qCDebug(KLEOPATRA_LOG) << "not a NetKey v3 card, giving up. Version:" << ci->appVersion();
+    if (ci->appVersion() < 3) {
+        qCDebug(KLEOPATRA_LOG) << "not a NetKey v3 (or later) card, giving up. Version:" << ci->appVersion();
         ci->setErrorMsg(QStringLiteral("NetKey v%1 cards are not supported.").arg(ci->appVersion()));
         return;
     }
@@ -761,6 +752,7 @@ Q_SIGNALS:
     void cardAdded(const std::string &serialNumber, const std::string &appName);
     void cardChanged(const std::string &serialNumber, const std::string &appName);
     void cardRemoved(const std::string &serialNumber, const std::string &appName);
+    void updateFinished();
     void oneTransactionFinished(const GpgME::Error &err);
 
 public Q_SLOTS:
@@ -851,53 +843,88 @@ private:
             }
 
             if ((nullSlot && command == updateTransaction.command)) {
-
-                std::vector<std::shared_ptr<Card> > newCards = update_cardinfo(gpgAgent);
-
-                KDAB_SYNCHRONIZED(m_mutex)
-                m_cardInfos = newCards;
-
-                bool anyLC = false;
-                std::string firstCardWithNullPin;
                 bool anyError = false;
-                for (const auto &newCard: newCards) {
-                    const auto serialNumber = newCard->serialNumber();
-                    const auto appName = newCard->appName();
-                    const auto matchingOldCard = std::find_if(oldCards.cbegin(), oldCards.cend(),
-                        [serialNumber, appName] (const std::shared_ptr<Card> &card) {
-                            return card->serialNumber() == serialNumber && card->appName() == appName;
-                        });
-                    if (matchingOldCard == oldCards.cend()) {
+
+                if (cardApp.serialNumber == "__all__" || cardApp.appName == "__all__") {
+                    std::vector<std::shared_ptr<Card> > newCards = update_cardinfo(gpgAgent);
+
+                    KDAB_SYNCHRONIZED(m_mutex) {
+                        m_cardInfos = newCards;
+                    }
+
+                    bool anyLC = false;
+                    std::string firstCardWithNullPin;
+                    for (const auto &newCard: newCards) {
+                        const auto serialNumber = newCard->serialNumber();
+                        const auto appName = newCard->appName();
+                        const auto matchingOldCard = std::find_if(oldCards.cbegin(), oldCards.cend(),
+                            [serialNumber, appName] (const std::shared_ptr<Card> &card) {
+                                return card->serialNumber() == serialNumber && card->appName() == appName;
+                            });
+                        if (matchingOldCard == oldCards.cend()) {
+                            qCDebug(KLEOPATRA_LOG) << "ReaderStatusThread: Card" << serialNumber << "with app" << appName << "was added";
+                            Q_EMIT cardAdded(serialNumber, appName);
+                        } else {
+                            if (*newCard != **matchingOldCard) {
+                                qCDebug(KLEOPATRA_LOG) << "ReaderStatusThread: Card" << serialNumber << "with app" << appName << "changed";
+                                Q_EMIT cardChanged(serialNumber, appName);
+                            }
+                            oldCards.erase(matchingOldCard);
+                        }
+                        if (newCard->canLearnKeys()) {
+                            anyLC = true;
+                        }
+                        if (newCard->hasNullPin() && firstCardWithNullPin.empty()) {
+                            firstCardWithNullPin = newCard->serialNumber();
+                        }
+                        if (newCard->status() == Card::CardError) {
+                            anyError = true;
+                        }
+                    }
+                    for (const auto &oldCard: oldCards) {
+                        qCDebug(KLEOPATRA_LOG) << "ReaderStatusThread: Card" << oldCard->serialNumber() << "with app" << oldCard->appName() << "was removed";
+                        Q_EMIT cardRemoved(oldCard->serialNumber(), oldCard->appName());
+                    }
+
+                    Q_EMIT firstCardWithNullPinChanged(firstCardWithNullPin);
+                    Q_EMIT anyCardCanLearnKeysChanged(anyLC);
+                } else {
+                    auto updatedCard = get_card_status(cardApp.serialNumber, cardApp.appName, gpgAgent);
+                    const auto serialNumber = updatedCard->serialNumber();
+                    const auto appName = updatedCard->appName();
+
+                    bool cardWasAdded = false;
+                    bool cardWasChanged = false;
+                    KDAB_SYNCHRONIZED(m_mutex) {
+                        const auto matchingCard = std::find_if(m_cardInfos.begin(), m_cardInfos.end(),
+                            [serialNumber, appName](const auto &card) {
+                                return card->serialNumber() == serialNumber && card->appName() == appName;
+                            });
+                        if (matchingCard == m_cardInfos.end()) {
+                            m_cardInfos.push_back(updatedCard);
+                            cardWasAdded = true;
+                        } else {
+                            cardWasChanged = (*updatedCard != **matchingCard);
+                            m_cardInfos[std::distance(m_cardInfos.begin(), matchingCard)] = updatedCard;
+                        }
+                        if (updatedCard->status() == Card::CardError) {
+                            anyError = true;
+                        }
+                    }
+                    if (cardWasAdded) {
                         qCDebug(KLEOPATRA_LOG) << "ReaderStatusThread: Card" << serialNumber << "with app" << appName << "was added";
                         Q_EMIT cardAdded(serialNumber, appName);
-                    } else {
-                        if (*newCard != **matchingOldCard) {
-                            qCDebug(KLEOPATRA_LOG) << "ReaderStatusThread: Card" << serialNumber << "with app" << appName << "changed";
-                            Q_EMIT cardChanged(serialNumber, appName);
-                        }
-                        oldCards.erase(matchingOldCard);
-                    }
-                    if (newCard->canLearnKeys()) {
-                        anyLC = true;
-                    }
-                    if (newCard->hasNullPin() && firstCardWithNullPin.empty()) {
-                        firstCardWithNullPin = newCard->serialNumber();
-                    }
-                    if (newCard->status() == Card::CardError) {
-                        anyError = true;
+                    } else if (cardWasChanged) {
+                        qCDebug(KLEOPATRA_LOG) << "ReaderStatusThread: Card" << serialNumber << "with app" << appName << "changed";
+                        Q_EMIT cardChanged(serialNumber, appName);
                     }
                 }
-                for (const auto &oldCard: oldCards) {
-                    qCDebug(KLEOPATRA_LOG) << "ReaderStatusThread: Card" << oldCard->serialNumber() << "with app" << oldCard->appName() << "was removed";
-                    Q_EMIT cardRemoved(oldCard->serialNumber(), oldCard->appName());
-                }
-
-                Q_EMIT firstCardWithNullPinChanged(firstCardWithNullPin);
-                Q_EMIT anyCardCanLearnKeysChanged(anyLC);
 
                 if (anyError) {
                     gpgAgent.reset();
                 }
+
+                Q_EMIT updateFinished();
             } else {
                 GpgME::Error err;
                 if (gpgHasMultiCardMultiAppSupport()) {
@@ -955,6 +982,8 @@ public:
                 q, &ReaderStatus::cardChanged);
         connect(this, &::ReaderStatusThread::cardRemoved,
                 q, &ReaderStatus::cardRemoved);
+        connect(this, &::ReaderStatusThread::updateFinished,
+                q, &ReaderStatus::updateFinished);
         connect(this, &::ReaderStatusThread::firstCardWithNullPinChanged,
                 q, &ReaderStatus::firstCardWithNullPinChanged);
         connect(this, &::ReaderStatusThread::anyCardCanLearnKeysChanged,
@@ -1077,6 +1106,13 @@ void ReaderStatus::updateStatus()
     d->ping();
 }
 
+void ReaderStatus::updateCard(const std::string &serialNumber, const std::string &appName)
+{
+    const CardApp cardApp = { serialNumber, appName };
+    const Transaction t = { cardApp, updateTransaction.command, nullptr, nullptr, nullptr };
+    d->addTransaction(t);
+}
+
 std::vector <std::shared_ptr<Card> > ReaderStatus::getCards() const
 {
     return d->cardInfos();
