@@ -53,15 +53,21 @@ QString Kleo::heuristicBaseDirectory(const QStringList &fileNames)
     }
     qCDebug(KLEOPATRA_LOG) << "dirs" << dirs;
     const QString candidate = longestCommonPrefix(dirs);
-    /* Special case handling for Outlook attachment temporary path.
+    /* Special case handling for Outlook and KMail attachment temporary path.
      * This is otherwise something like:
      * c:\users\username\AppData\Local\Microsoft\Windows\INetCache\
      *      Content.Outlook\ADSDFG9\foo.txt
      *
+     * For KMail it is usually /tmp/messageviewer/foo
+     *
+     * Both are paths that are unlikely to be the target path to save the
+     * decrypted attachment.
+     *
      * This is very common when encrypted attachments are opened
-     * within outlook.
+     * within Outlook or KMail.
      */
-    if (candidate.contains(QStringLiteral("Content.Outlook"))) {
+    if (candidate.contains(QStringLiteral("Content.Outlook")) ||
+        candidate.contains(QStringLiteral("messageviewer"))) {
         return QStandardPaths::writableLocation(QStandardPaths::DocumentsLocation);
     }
     const int idx = candidate.lastIndexOf(QLatin1Char('/'));
@@ -153,9 +159,13 @@ bool Kleo::recursivelyCopy(const QString &src,const QString &dest)
 
 bool Kleo::moveDir(const QString &src, const QString &dest)
 {
-    if (QStorageInfo(src).device() == QStorageInfo(dest).device()) {
-        // Easy same partition we can use qt.
-        return QFile::rename(src, dest);
+    // Need an existing path to query the device
+    const QString parentDest = QFileInfo(dest).dir().absolutePath();
+    const auto srcDevice = QStorageInfo(src).device();
+    if (!srcDevice.isEmpty() && srcDevice == QStorageInfo(parentDest).device() &&
+        QFile::rename(src, dest)) {
+        qCDebug(KLEOPATRA_LOG) << "Renamed" << src << "to" << dest;
+        return true;
     }
     // first copy
     if (!recursivelyCopy(src, dest)) {
